@@ -12,7 +12,7 @@ from .api import create_request_events_bp, create_requests_bp
 from .ui import create_ui_blueprint
 
 __all__ = (
-    'create_ui_blueprint',
-    'create_requests_bp',
-    'create_request_events_bp',
+    "create_ui_blueprint",
+    "create_requests_bp",
+    "create_request_events_bp",
 )
